use std::collections::HashMap;
use std::sync::Arc;

use enum_map::EnumMap;
use serde::Deserialize;

use deckster_shared::path::KnobPosition;
use deckster_shared::style::KnobStyle;

#[derive(Debug, Deserialize)]
pub struct File {
    pub id: Option<String>,
    pub knobs: HashMap<KnobPosition, Knob>,
}

#[derive(Debug)]
pub struct Page {
    pub id: String,
    pub knobs: EnumMap<KnobPosition, Arc<Knob>>,
}

#[derive(Debug, Default, Deserialize)]
pub struct Knob {
    #[serde(default, flatten)]
    pub base_style: KnobStyle,

    #[serde(default = "super::get_default_host_id")]
    pub host: Box<str>,
    pub handler: Box<str>,
    pub config: Arc<toml::Table>,
}
